diff mbox series

[v2] clk: imx6q: demote warning about pre-boot ldb_di_clk reparenting

Message ID 20210118113032.21178-1-a.fatoum@pengutronix.de (mailing list archive)
State Awaiting Upstream, archived
Headers show
Series [v2] clk: imx6q: demote warning about pre-boot ldb_di_clk reparenting | expand

Commit Message

Ahmad Fatoum Jan. 18, 2021, 11:30 a.m. UTC
Since 5d283b083800 ("clk: imx6: Fix procedure to switch the parent
of LDB_DI_CLK"), the clock driver warns if ldb_di\d_sel is changed
from reset value on system boot. This warning is printed even if
the bootloader (or a previous kernel that did kexec) followed the
correct procedure for glitch-free reparenting.

As such systems are doing everything correctly, a warning is too
harsh. Demote to a notice, so users are still alerted, but without
cluttering a loglevel=5 boot.

While at it, add the words "possible glitch" into the log message, to
make it more user-friendly.

Signed-off-by: Ahmad Fatoum <a.fatoum@pengutronix.de>
---
Cc: Fabio Estevam <fabio.estevam@nxp.com>

v1 -> v2:
  - added "possile glitch" to error message to make more useful
    (Stephen)
---
 drivers/clk/imx/clk-imx6q.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

Comments

Fabio Estevam Jan. 19, 2021, 2:10 a.m. UTC | #1
Hi Ahmad,

On Mon, Jan 18, 2021 at 8:30 AM Ahmad Fatoum <a.fatoum@pengutronix.de> wrote:
>
> Since 5d283b083800 ("clk: imx6: Fix procedure to switch the parent
> of LDB_DI_CLK"), the clock driver warns if ldb_di\d_sel is changed
> from reset value on system boot. This warning is printed even if
> the bootloader (or a previous kernel that did kexec) followed the
> correct procedure for glitch-free reparenting.
>
> As such systems are doing everything correctly, a warning is too
> harsh. Demote to a notice, so users are still alerted, but without
> cluttering a loglevel=5 boot.
>
> While at it, add the words "possible glitch" into the log message, to
> make it more user-friendly.
>
> Signed-off-by: Ahmad Fatoum <a.fatoum@pengutronix.de>

Reviewed-by: Fabio Estevam <festevam@gmail.com>
diff mbox series

Patch

diff --git a/drivers/clk/imx/clk-imx6q.c b/drivers/clk/imx/clk-imx6q.c
index b2ff187cedab..521d6136d22c 100644
--- a/drivers/clk/imx/clk-imx6q.c
+++ b/drivers/clk/imx/clk-imx6q.c
@@ -338,10 +338,10 @@  static void init_ldb_clks(struct device_node *np, void __iomem *ccm_base)
 	of_assigned_ldb_sels(np, &sel[0][3], &sel[1][3]);
 
 	for (i = 0; i < 2; i++) {
 		/* Warn if a glitch might have been introduced already */
 		if (sel[i][0] != 3) {
-			pr_warn("ccm: ldb_di%d_sel already changed from reset value: %d\n",
-				i, sel[i][0]);
+			pr_notice("ccm: possible glitch: ldb_di%d_sel already changed from reset value: %d\n",
+				  i, sel[i][0]);
 		}
 
 		if (sel[i][0] == sel[i][3])
@@ -338,10 +338,10 @@  static void init_ldb_clks(struct device_node *np, void __iomem *ccm_base)
 
 	for (i = 0; i < 2; i++) {
-		/* Warn if a glitch might have been introduced already */
+		/* Print a notice if a glitch might have been introduced already */
 		if (sel[i][0] != 3) {